@@ -1,8 +1,10 @@
 import sys
 
+import cbmcodecs
+
 from t64 import T64ImageReader
 
 
 with T64ImageReader(sys.argv[1]) as t:
-    for line in t.directory('ascii'):
+    for line in t.directory():
         print(line)
