@@ -24,5 +24,5 @@ class DirEntry:
         return bool(self._disk_type & 0x80)
 
     def contents(self):
-        img_end = self.img_start+self.end_addr-self.startaddr
+        img_end = self.img_start+self.end_addr-self.start_addr
         return self.image.map[self.img_start:img_end]
