@@ -7,6 +7,7 @@ import struct
 from pathlib import Path
 
 from .dir_entry import DirEntry
+from .magic import is_valid_image
 
 
 log = logging.getLogger(__name__)
@@ -19,10 +20,10 @@ class T64ImageReader:
         self.map = None
 
     def open(self):
+        if not is_valid_image(self.filepath):
+            raise ValueError("Invalid file format")
         self.fileh = self.filepath.open('rb')
         self.map = mmap.mmap(self.fileh.fileno(), 0, mmap.MAP_PRIVATE, mmap.ACCESS_READ)
-        if self.map[:3] != b'C64':
-            raise ValueError("Invalid file format, "+str(self.map[:32]))
 
         self.version, self.max_entries, self.used_entries = struct.unpack('<HHH', self.map[0x20:0x26])
         self.tape_name = self.map[0x28:0x40]
@@ -50,7 +51,7 @@ class T64ImageReader:
         if self.fileh:
             self.fileh.close()
 
-    def directory(self, encoding='petscii-c64en-uc', drive=0):
+    def directory(self, pattern=b'', encoding='petscii-c64en-uc', drive=0):
         try:
             _ = codecs.lookup(encoding)
         except LookupError:
@@ -60,13 +61,14 @@ class T64ImageReader:
         yield '{} "{:24}"'.format(drive, self.tape_name.decode(encoding))
 
         for entry in self.entries:
-            size_blocks = math.ceil((entry.end_addr-entry.start_addr) / 254)
-            closed_ch = ' ' if entry.closed else '*'
-            disk_type = entry.disk_type
-            if entry.protected:
-                disk_type += '<'
-            name = '"'+entry.name.decode(encoding)+'"'
-            yield '{!s:5}{:18}{}{}'.format(size_blocks, name, closed_ch, disk_type)
+            if entry.name.startswith(pattern):
+                size_blocks = math.ceil((entry.end_addr-entry.start_addr) / 254)
+                closed_ch = ' ' if entry.closed else '*'
+                disk_type = entry.disk_type
+                if entry.protected:
+                    disk_type += '<'
+                name = '"'+entry.name.decode(encoding)+'"'
+                yield '{!s:5}{:18}{}{}'.format(size_blocks, name, closed_ch, disk_type)
 
     def iterdir(self):
         yield from self.entries
